pub struct InputEvent {
pub time: SystemTime,
pub code: EventCode,
pub state: KeyState,
}Expand description
InputEvent is a qsk-specific struct modeled in large part after evdev_rs::InputEvent. Although evdev_rs::InputEvent actually supports a large range of Linux-specific input events, we focus here on keyboard and synchronization events specifically since keyboard events are the primary concern of qsk initially and synchronization needs to be represented. Abstracting away from Linux-specific event handling in this way will enable us to support input event systems for other OSes in the future.
Fields
time: SystemTimecode: EventCodestate: KeyStateTrait Implementations
Sourceimpl Clone for InputEvent
impl Clone for InputEvent
Sourcefn clone(&self) -> InputEvent
fn clone(&self) -> InputEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for InputEvent
Sourceimpl Debug for InputEvent
impl Debug for InputEvent
Sourceimpl<'de> Deserialize<'de> for InputEvent
impl<'de> Deserialize<'de> for InputEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InputEvent
Sourceimpl Hash for InputEvent
impl Hash for InputEvent
Sourceimpl PartialEq for InputEvent
impl PartialEq for InputEvent
Sourceimpl Serialize for InputEvent
impl Serialize for InputEvent
impl StructuralPartialEq for InputEvent