InputEvent

Struct InputEvent 

pub struct InputEvent {
    pub time: SystemTime,
    pub code: EventCode,
    pub state: KeyState,
}
InputEvent is a qsk-specific struct modeled in large part after evdev_rs::InputEvent. Although evdev_rs::InputEvent actually supports a large range of Linux-specific input events, we focus here on keyboard and synchronization events specifically since keyboard events are the primary concern of qsk initially and synchronization needs to be represented. Abstracting away from Linux-specific event handling in this way will enable us to support input event systems for other OSes in the future.

Fields

time: SystemTimecode: EventCodestate: KeyState